==> piwigo-2.1.3.tbz: www/piwigo/language/ka_GE/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'განახლება';
$lang['Upgrade from version %s to %s'] = 'განახლება %s ვერსიიდან %s ვერსიამდე';
$lang['Statistics'] = 'სტატისტიკა';
$lang['total upgrade time'] = 'განახლების საერთო დრო';
$lang['total SQL time'] = 'SQL საერთო დრო';
$lang['SQL queries'] = 'SQL მოთხოვნა';
$lang['Upgrade informations'] = 'ინფორმაცია განახლებებზე';
$lang['Perform a maintenance check in [Administration>tools>Maintenance] if you encounter any problem.'] = 'განახორციელეთ მომსახურება [ადმინისტრირება>სპეციალური>მომსახურება] თუკი შეგექმნათ რაიმე პრობლემა.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'მხოლოდ ადმინისტრტორს შეუძლია განახლების გაშვება: შეამოწმეთ ქვევით.';
$lang['You do not have access rights to run upgrade'] = 'თქვენ არ გაქვთ განახლების გაშვების უფლება';

// Upgrade informations from upgrade_1.3.1.php
$lang['All sub-categories of private categories become private'] = 'პრივატული (კერძო) კატეგორიის ყველა ქვეკატეგორია იქნება პრივატული';
$lang['User permissions and group permissions have been erased'] = 'მომხმარებლების და ჯგუფების დაშვების უფლებები წაშლილია';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'მხოლოდ ესკიზების პრეფიქსები და ვებმასტერის ფოსტის მისამართი იქნა შენახული წინა კონფიგურაციიდან';

$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'ეს გვერდი გთავაზობთ მონაცემთა ბაზის მოდერნიზაციას,თქვენი Piwigo ძველი ვერსიიდან ახალ ვერსიამდე. განახლების დამხმარე საშუალება ფიქრობს,რომ თქვენ ამჟამად იყენებთ <b> ვერსია %s </b> (ან ეკვივალენტურს).';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'სასურველია,რომ შემდეგი პლაგინები დეზაქტივირებული იყოს. თქვენ უნდა შეამოწმოთ პლაგინების განახლება მანამდე,სანამ მოახდენთ მათ აქტივაციას:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] =' %s, მდე ?>, ჩავსვათ:';
?>

==> piwigo-2.3.3.tbz: www/piwigo/language/ka_GE/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'განახლება';
$lang['Upgrade from version %s to %s'] = 'განახლება %s ვერსიიდან %s ვერსიამდე';
$lang['Statistics'] = 'სტატისტიკა';
$lang['total upgrade time'] = 'განახლების საერთო დრო';
$lang['total SQL time'] = 'SQL საერთო დრო';
$lang['SQL queries'] = 'SQL მოთხოვნა';
$lang['Upgrade informations'] = 'ინფორმაცია განახლებებზე';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'განახორციელეთ მომსახურება [ადმინისტრირება>ინსტრუმენტები>მომსახურება] თუკი შეგექმნათ რაიმე პრობლემა.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'მხოლოდ ადმინისტრტორს შეუძლია განახლების გაშვება: შეამოწმეთ ქვევით.';
$lang['You do not have access rights to run upgrade'] = 'თქვენ არ გაქვთ განახლების გაშვების უფლება';
$lang['All sub-albums of private albums become private'] = 'პრივატული (კერძო) კატეგორიის ყველა ქვეკატეგორია იქნება პრივატული';
$lang['User permissions and group permissions have been erased'] = 'მომხმარებლების და ჯგუფების დაშვების უფლებები წაშლილია';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'მხოლოდ ესკიზების პრეფიქსები და ვებმასტერის ფოსტის მისამართი იქნა შენახული წინა კონფიგურაციიდან';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'ეს გვერდი გთავაზობთ მონაცემთა ბაზის მოდერნიზაციას,თქვენი Piwigo ძველი ვერსიიდან ახალ ვერსიამდე. განახლების დამხმარე საშუალება ფიქრობს,რომ თქვენ ამჟამად იყენებთ <b> ვერსია %s </b> (ან ეკვივალენტურს).';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'სასურველია,რომ შემდეგი პლაგინები დეზაქტივირებული იყოს. თქვენ უნდა შეამოწმოთ პლაგინების განახლება მანამდე,სანამ მოახდენთ მათ აქტივაციას:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] =' %s, მდე ?>, ჩავსვათ:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'უსაფრთხოების მიზნით შემდეგი თემები გამორთულია. თქვენ უნდა შეამოწმოთთემების განახლება? სანამ მათ ახლიდან ჩართავთ:';
?>
